@@ -2,27 +2,17 @@ use vars qw(@t $ff $ss $folderfirst $sortstate);
 $folderfirst = param('folderfirst') ? 1 : 0;
 $ss          = param('sort')        ? 1 : 0;
 folderFirst($folderfirst);
-
 sub ShowBookmarks
 {
     loadTree($m_hrSettings->{tree}{links});
     *t = \@{$HTML::Menu::TreeView::TreeView[0]};
     applyRights(\@t);
-    my %parameter = (
-                     path   => $m_hrSettings->{cgi}{bin} . '/templates',
-                     style  => $m_sStyle,
-                     title  => " ",
-                     server => $m_hrSettings->{serverName},
-                     id     => 'ShowBookmarks',
-                     class  => 'max',
-    );
-    my $window = new HTML::Window(\%parameter);
-    $m_sContent .= br() . $window->windowHeader();
+    print br().'<div class="showTables">';
+
     _showBookmarksNavi();
-    $m_sContent .= qq(<table align="center"  border="0" cellpadding="0" cellspacing="0"  width="100%" summary="linkLayout"><tr><td valign="top">);
-    $m_sContent .= Tree(\@t);
-    $m_sContent .= qq(</td></tr></table>);
-    $m_sContent .= $window->windowFooter();
+    print qq(<table class="ShowTables" style="padding-top:1.65em;" align="center"  border="0" cellpadding="0" cellspacing="0"  width="100%" summary="linkLayout"><tr><td valign="top">);
+    print Tree(\@t);
+    print qq(</td></tr></table></div>);
 }
 
 sub _showBookmarksNavi
@@ -32,76 +22,66 @@ sub _showBookmarksNavi
     sortTree($ss);
     $sortstate = $ss;
     $ss = $ss ? 0 : 1;
-    $m_sContent .=
+    print 
         '<div align="left">' 
       . br()
       . a(
           {
-           class => $sortstate ? 'currentLink' : 'link',
-           href  => "$ENV{SCRIPT_NAME}?action=links&sort=$ss&folderfirst=$folderfirst",
-           title => translate('sort')
+           class => 'link',
+           href  => "javascript:requestURI('$ENV{SCRIPT_NAME}?action=links&sort=1','$m_sAction','$m_sTitle')",
+           title => translate('test')
           },
           translate('sort')
-      ) . '&#160;|&#160;';
-    $m_sContent .= a(
+      ) . ' | ';
+    print a(
                      {
                       class => $folderfirst ? 'currentLink' : 'link',
-                      href  => "$ENV{SCRIPT_NAME}?action=links&sort=$sortstate&folderfirst=$ff",
+                      href  => "javascript:requestURI('$ENV{SCRIPT_NAME}?action=links&sort=$sortstate&folderfirst=$ff','$m_sAction','$m_sTitle')",
                       title => translate('folderFirst')
                      },
                      translate('folderFirst')
-    ) . '&#160;|&#160;';
-    $m_sContent .= a(
+    ) . ' | ';
+    print a(
                      {
                       class => 'link',
-                      href  => "$ENV{SCRIPT_NAME}?action=ExportOperaBookmarks",
+                      href  => "javascript:requestURI('$ENV{SCRIPT_NAME}?action=ExportOperaBookmarks','$m_sAction','$m_sTitle')",
                       title => translate('ExportOperaBookmarks')
                      },
                      translate('ExportOperaBookmarks')
     );
-    $m_sContent .= '&#160;|&#160;'
+    print ' | '
       . a(
           {
            class => 'link',
-           href  => "$ENV{SCRIPT_NAME}?action=editTreeview&dump=links",
+           href  => "javascript:requestURI('$ENV{SCRIPT_NAME}?action=editTreeview&dump=links','$m_sAction','$m_sTitle')",
            title => translate('edit')
           },
           translate('edit')
       ) if ($m_nRight >= $m_oDatabase->getActionRight('editTreeview'));
-    $m_sContent .= '&#160;|&#160;'
+    print ' | '
       . a(
           {
            class => $m_sAction eq "ImportOperaBookmarks"
            ? 'currentLink'
            : 'link',
-           href  => "$ENV{SCRIPT_NAME}?action=ImportOperaBookmarks",
+           href  => "javascript:requestURI('$ENV{SCRIPT_NAME}?action=ImportOperaBookmarks','$m_sAction','$m_sTitle')",
            title => translate("ImportOperaBookmarks")
           },
           translate("ImportOperaBookmarks")
       ) if ($m_nRight >= $m_oDatabase->getActionRight('ImportOperaBookmarks'));
-    $m_sContent .= '&#160;|&#160;'
+    print ' | '
       . a(
           {
            class => $m_sAction eq "ImportFireFoxBookmarks"
            ? 'currentLink'
            : 'link',
-           href  => "$ENV{SCRIPT_NAME}?action=ImportFireFoxBookmarks&dump=links",
+           href  => "javascript:requestURI('$ENV{SCRIPT_NAME}?action=ImportFireFoxBookmarks','$m_sAction','$m_sTitle')",
            title => translate('importFireFox'),
            id    => 'ShareLink'
           },
           translate('importFireFox')
       ) if ($m_nRight >= $m_oDatabase->getActionRight('ImportFireFoxBookmarks'));
-    my $moveLink = translate('DragShareLink');
-    $m_sContent .= '&#160;|&#160;'
-      . a(
-          {
-           class   => 'link',
-           href    => qq|javascript:window.open(' $m_hrSettings->{cgi}{serverName}$ENV{SCRIPT_NAME}?dump=links&action=newTreeviewEntry&addBookMark='+escape(location.href)+'&title='+escape(document.title),'Bookmark');void(0)|,
-           title   => translate('DragShareLink'),
-           onclick => "alert('$moveLink');return false;",
-          },
-          translate('shareLink')
-      ) if ($m_nRight >= $m_oDatabase->getActionRight('newTreeviewEntry'));
+
 
     $msContent .= q|</div>| . br();
 }
@@ -110,23 +90,23 @@ sub ExportOperaBookmarks
 {
     loadTree($m_hrSettings->{tree}{links});
     *t = \@{$HTML::Menu::TreeView::TreeView[0]};
-    my %parameter = (
-                     path   => $m_hrSettings->{cgi}{bin} . '/templates',
-                     style  => $m_sStyle,
-                     title  => " ",
-                     server => $m_hrSettings->{serverName},
-                     id     => 'ShowBookmarks',
-                     class  => 'min',
-    );
-    my $window = new HTML::Window(\%parameter);
-    $m_sContent .= br() . $window->windowHeader();
+#     my %parameter = (
+#                      path   => $m_hrSettings->{cgi}{bin} . '/templates',
+#                      style  => $m_sStyle,
+#                      title  => " ",
+#                      server => $m_hrSettings->{serverName},
+#                      id     => 'ShowBookmarks',
+#                      class  => 'min',
+#     );
+#     my $window = new HTML::Window(\%parameter);
+#     print br() . $window->windowHeader();
     _showBookmarksNavi();
-    $m_sContent .= qq(<table align="center"  border="0" cellpadding="0" cellspacing="0"  width="100%" summary="linkLayout"><tr><td align="center" valign="top">);
-    $m_sContent .= qq(<textarea style="width:98%;height:800px;">\nOpera Hotlist version 2.0\nOptions: encoding = utf-8, version=3\n);
+    print qq(<table align="center"  border="0" cellpadding="0" cellspacing="0"  width="100%" summary="linkLayout"><tr><td align="center" valign="top">);
+    print qq(<textarea style="width:98%;height:800px;">\nOpera Hotlist version 2.0\nOptions: encoding = utf-8, version=3\n);
     &_rec(\@t);
-    $m_sContent .= qq(</textarea><br/>);
-    $m_sContent .= qq(</td></tr></table>);
-    $m_sContent .= $window->windowFooter();
+    print qq(</textarea><br/>);
+    print qq(</td></tr></table>);
+#     print $window->windowFooter();
 }
 
 sub _rec
@@ -136,12 +116,12 @@ sub _rec
         if (defined @$tree[$i]) {
             my $text = defined @$tree[$i]->{text} ? @$tree[$i]->{text} : '';
             if (defined @{@$tree[$i]->{subtree}}) {
-                $m_sContent .= "#FOLDER\n\tID=@$tree[$i]->{rid}\n\tNAME=$text\n\tUNIQUEID=@$tree[$i]->{rid}\n";
+                print "#FOLDER\n\tID=@$tree[$i]->{rid}\n\tNAME=$text\n\tUNIQUEID=@$tree[$i]->{rid}\n";
                 _rec(\@{@$tree[$i]->{subtree}});
-                $m_sContent .= "-\n\n";
+                print "-\n\n";
             } else {
                 my $hrf = defined @$tree[$i]->{href} ? @$tree[$i]->{href} : '';
-                $m_sContent .= "#URL\n\tID=@$tree[$i]->{rid}\n\tNAME=$text\n\tURL=$hrf\n\tUNIQUEID=@$tree[$i]->{rid}\n";
+                print "#URL\n\tID=@$tree[$i]->{rid}\n\tNAME=$text\n\tURL=$hrf\n\tUNIQUEID=@$tree[$i]->{rid}\n";
             }
         }
     }
@@ -153,10 +133,10 @@ sub ImportOperaBookmarks
     my $choosefile  = translate('choosefile');
     my $newFolder   = translate('newFolder');
     my $b_NewFolder = param('newFolder') ? param('newFolder') : '';
-    $m_sContent .= qq|
+    print qq|
 <br/><div align="center">
 <font size="+1">Upload Opera Bookmarks</font><br/><br/>
-<form name="upload" action="$ENV{SCRIPT_NAME}" method="post" accept-charset="utf-8" accept="text/*" enctype="multipart/form-data" onSubmit="return confirm('$save ?');">
+<form name="upload" method="post" accept-charset="utf-8" accept="text/*" enctype="multipart/form-data" onSubmit="submitForm(this,'$m_sAction','$m_sTitle');return false;">
 <input name="file" type="file" size ="30" title="$choosefile"/>
 $newFolder<input type="checkbox" name="newFolder"/>
 <input type="submit" value="$save"/>
@@ -224,10 +204,10 @@ sub ImportFireFoxBookmarks
     my $choosefile  = translate('choosefile');
     my $newFolder   = translate('newFolder');
     my $b_NewFolder = param('newFolder') ? param('newFolder') : '';
-    $m_sContent .= qq|
+    print qq|
 <br/><div align="center">
 <font size="+1">Upload Firefox Bookmarks</font><br/><br/>
-<form name="upload" action="$ENV{SCRIPT_NAME}" method="post" accept-charset="utf-8" accept="text/*" enctype="multipart/form-data" onSubmit="return confirm('$save ?');">
+<form name="upload" action="$ENV{SCRIPT_NAME}" method="post" accept-charset="utf-8" accept="text/*" enctype="multipart/form-data" onSubmit="submitForm(this,'$m_sAction','$m_sTitle');return false;">
 <input name="file" type="file" size ="30" title="$choosefile"/>
 $newFolder<input type="checkbox"  name="newFolder"/>
 <input type="submit" value="$save"/>
