@@ -1,46 +1,57 @@
 $VAR1 = {
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'version' => '0.91',
           'floodtime' => 10,
-          'language' => 'en',
+          'scriptAlias' => 'cgi-bin',
           'cgi' => {
-                     'cookiePath' => '/',
-                     'bin' => '/var/www/cgi-bin',
-                     'expires' => '+1y',
-                     'style' => 'mysql',
-                     'alias' => 'cgi-bin',
-                     'DocumentRoot' => '/var/www/htdocs',
                      'title' => 'MySQL::Admin',
+                     'expires' => '+1y',
+                     'bin' => '/var/www/cgi-bin',
+                     'style' => 'mysql',
+                     'DocumentRoot' => '/var/www/htdocs',
+                     'cookiePath' => '/',
+                     'alias' => 'cgi-bin',
                      'serverName' => 'localhost'
                    },
           'config' => '/var/www/cgi-bin/config/settings.pl',
-          'database' => {
-                          'CurrentHost' => 'localhost',
-                          'name' => 'LZE',
-                          'CurrentPass' => 'keinz',
-                          'CurrentUser' => 'root',
-                          'CurrentDb' => 'LZE',
-                          'user' => 'root',
-                          'host' => 'localhost',
-                          'password' => 'keinz'
-                        },
-          'version' => '0.9',
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'mod' => 0,
+          'news' => {
+                      'maxlength' => '2000',
+                      'right' => 5,
+                      'messages' => '5',
+                      'captcha' => 3
+                    },
+          'language' => 'en',
+          'mod' => 'n',
           'admin' => {
                        'password' => 'testpass'
                      },
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'tree' => {
+                      'navigation' => '/var/www/cgi-bin/config/tree.pl',
+                      'links' => '/var/www/cgi-bin/config/links.pl'
+                    },
           'files' => {
-                       'owner' => 'lze',
                        'group' => 'lze',
+                       'owner' => 'lze',
                        'chmod' => '0755'
                      },
-          'scriptAlias' => 'cgi-bin',
+          'database' => {
+                          'host' => 'localhost',
+                          'user' => 'root',
+                          'password' => '',
+                          'CurrentPass' => '',
+                          'CurrentDb' => 'LZE',
+                          'name' => 'LZE',
+                          'CurrentHost' => 'localhost',
+                          'CurrentUser' => 'root'
+                        },
           'uploads' => {
-                         'path' => '/var/www/htdocs/download',
                          'chmod' => 438,
-                         'maxlength' => 21000000
-                       }
+                         'maxlength' => 21000000,
+                         'path' => '/var/www/htdocs//download'
+                       },
+          'defaultAction' => 'ShowDatabases'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
